@@ -37,6 +37,7 @@
 #include <QTimer>
 #include <QXmlQuery>
 
+#include <kcoreaddons_version.h>
 #include <KMessageBox>
 #include <KActionCollection>
 #include <KFontAction>
@@ -108,14 +109,6 @@ Worksheet::~Worksheet()
 void Worksheet::loginToSession()
 {
     m_session->login();
-#ifdef WITH_EPS
-    if (Cantor::LatexRenderer::isLatexAvailable())
-        session()->setTypesettingEnabled(Settings::self()->typesetDefault());
-    else
-        session()->setTypesettingEnabled(false);
-#else
-    session()->setTypesettingEnabled(false);
-#endif
 }
 
 void Worksheet::print(QPrinter* printer)
@@ -123,6 +116,7 @@ void Worksheet::print(QPrinter* printer)
     m_epsRenderer.useHighResolution(true);
     m_mathRenderer.useHighResolution(true);
     m_isPrinting = true;
+
     QRect pageRect = printer->pageRect();
     qreal scale = 1; // todo: find good scale for page size
     // todo: use epsRenderer()->scale() for printing ?
@@ -133,6 +127,7 @@ void Worksheet::print(QPrinter* printer)
     QPainter painter(printer);
     painter.scale(scale, scale);
     painter.setRenderHint(QPainter::Antialiasing);
+
     WorksheetEntry* entry = firstEntry();
     qreal y = TopMargin;
 
@@ -1458,19 +1453,15 @@ bool Worksheet::loadCantorWorksheet(const KZip& archive)
 
     qDebug()<<"loading entries";
     QDomElement expressionChild = root.firstChildElement();
-    WorksheetEntry* entry = nullptr;
     while (!expressionChild.isNull()) {
         QString tag = expressionChild.tagName();
         // Don't add focus on load
-        entry = appendEntry(typeForTagName(tag), false);
+        auto* entry = appendEntry(typeForTagName(tag), false);
         if (entry)
         {
             entry->setContent(expressionChild, archive);
             if (m_readOnly)
-            {
                 entry->setAcceptHoverEvents(false);
-                entry = nullptr;
-            }
         }
 
         expressionChild = expressionChild.nextSiblingElement();
@@ -1851,10 +1842,10 @@ void Worksheet::populateMenu(QMenu *menu, QPointF pos)
                 convertTo->addAction(QIcon::fromTheme(QLatin1String("insert-page-break")), i18n("Page Break"), entry, &WorksheetEntry::converToPageBreakEntry);
 
             if (entry->type() != HorizontalRuleEntry::Type)
-                convertTo->addAction(QIcon(), i18n("Horizontal Line"), entry, &WorksheetEntry::convertToHorizontalRuleEntry);
+                convertTo->addAction(QIcon::fromTheme(QLatin1String("newline")), i18n("Horizontal Line"), entry, &WorksheetEntry::convertToHorizontalRuleEntry);
 
             if (entry->type() != HierarchyEntry::Type)
-                convertTo->addAction(QIcon(), i18n("Hierarchy Entry"), entry, &WorksheetEntry::convertToHierarchyEntry);
+                convertTo->addAction(QIcon::fromTheme(QLatin1String("view-list-tree")), i18n("Hierarchy Entry"), entry, &WorksheetEntry::convertToHierarchyEntry);
 
             //"Insert After" menu
             QMenu* insert = new QMenu(i18n("Insert After"), menu);
@@ -1871,9 +1862,11 @@ void Worksheet::populateMenu(QMenu *menu, QPointF pos)
             insert->addAction(QIcon::fromTheme(QLatin1String("text-x-tex")), i18n("LaTeX"), entry, SLOT(insertLatexEntry()));
     #endif
             insert->addAction(QIcon::fromTheme(QLatin1String("image-x-generic")), i18n("Image"), entry, SLOT(insertImageEntry()));
+            insert->addSeparator();
+            insert->addAction(QIcon::fromTheme(QLatin1String("newline")), i18n("Horizontal Line"), entry, SLOT(insertHorizontalRuleEntry()));
             insert->addAction(QIcon::fromTheme(QLatin1String("insert-page-break")), i18n("Page Break"), entry, SLOT(insertPageBreakEntry()));
-            insert->addAction(QIcon(), i18n("Horizontal Line"), entry, SLOT(insertHorizontalRuleEntry()));
-            insert->addAction(QIcon(), i18n("Hierarchy Entry"), entry, SLOT(insertHierarchyEntry()));
+            insert->addSeparator();
+            insert->addAction(QIcon::fromTheme(QLatin1String("view-list-tree")), i18n("Hierarchy Entry"), entry, SLOT(insertHierarchyEntry()));
 
             //"Insert Before" menu
             QMenu* insertBefore = new QMenu(i18n("Insert Before"), menu);
@@ -1889,9 +1882,11 @@ void Worksheet::populateMenu(QMenu *menu, QPointF pos)
             insertBefore->addAction(QIcon::fromTheme(QLatin1String("text-x-tex")), i18n("LaTeX"), entry, SLOT(insertLatexEntryBefore()));
     #endif
             insertBefore->addAction(QIcon::fromTheme(QLatin1String("image-x-generic")), i18n("Image"), entry, SLOT(insertImageEntryBefore()));
+            insertBefore->addSeparator();
+            insertBefore->addAction(QIcon::fromTheme(QLatin1String("newline")), i18n("Horizontal Line"), entry, SLOT(insertHorizontalRuleEntryBefore()));
             insertBefore->addAction(QIcon::fromTheme(QLatin1String("insert-page-break")), i18n("Page Break"), entry, SLOT(insertPageBreakEntryBefore()));
-            insertBefore->addAction(QIcon(), i18n("Horizontal Line"), entry, SLOT(insertHorizontalRuleEntryBefore()));
-            insertBefore->addAction(QIcon(), i18n("Hierarchy Entry"), entry, SLOT(insertHierarchyEntryBefore()));
+            insertBefore->addSeparator();
+            insertBefore->addAction(QIcon::fromTheme(QLatin1String("view-list-tree")), i18n("Hierarchy Entry"), entry, SLOT(insertHierarchyEntryBefore()));
         } else {
             QMenu* insertMenu = new QMenu(i18n("Insert"));
             insertMenu->setIcon(QIcon::fromTheme(QLatin1String("insert-table-row")));
@@ -1905,13 +1900,21 @@ void Worksheet::populateMenu(QMenu *menu, QPointF pos)
             insertMenu->addAction(QIcon::fromTheme(QLatin1String("text-x-tex")), i18n("LaTeX"), this, &Worksheet::appendLatexEntry);
     #endif
             insertMenu->addAction(QIcon::fromTheme(QLatin1String("image-x-generic")), i18n("Image"), this, &Worksheet::appendImageEntry);
+            insertMenu->addSeparator();
+            insertMenu->addAction(QIcon::fromTheme(QLatin1String("newline")), i18n("Horizontal Line"), this, &Worksheet::appendHorizontalRuleEntry);
             insertMenu->addAction(QIcon::fromTheme(QLatin1String("insert-page-break")), i18n("Page Break"), this, &Worksheet::appendPageBreakEntry);
-            insertMenu->addAction(QIcon(), i18n("Horizontal Line"), this, &Worksheet::appendHorizontalRuleEntry);
-            insertMenu->addAction(QIcon(), i18n("Hierarchy Entry"), this, &Worksheet::appendHierarchyEntry);
+            insertMenu->addSeparator();
+            insertMenu->addAction(QIcon::fromTheme(QLatin1String("view-list-tree")), i18n("Hierarchy Entry"), this, &Worksheet::appendHierarchyEntry);
 
             menu->addMenu(insertMenu);
+
+            //"Show help" for backend's documentation
+            menu->addSeparator();
+            menu->addAction(QIcon::fromTheme(QLatin1String("help-hint")), i18n("Show Help"), this,
+                                        [=] () { requestDocumentation(QString()); });
         }
 
+        //evaluate the whole worksheet or interrupt the current calculation
         menu->addSeparator();
         if (!isRunning())
             menu->addAction(QIcon::fromTheme(QLatin1String("system-run")), i18n("Evaluate Worksheet"),
@@ -2066,7 +2069,11 @@ void Worksheet::initActions()
     // Font Family
     m_fontAction = new KFontAction(i18nc("@action", "&Font"), m_collection);
     m_richTextActionList.append(m_fontAction);
+#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 78, 0)
     connect(m_fontAction, &KFontAction::textTriggered, this, &Worksheet::setFontFamily);
+#else
+    connect(m_fontAction, QOverload<const QString&>::of(&KFontAction::triggered), this, &Worksheet::setFontFamily);
+#endif
 
     // Font Size
     m_fontSizeAction = new KFontSizeAction(i18nc("@action", "Font &Size"), m_collection);
